// java wrapper for vtkImagePlaneWidget object
//

package vtk;
import vtk.*;

public class vtkImagePlaneWidget extends vtkPolyDataSourceWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void PlaceWidget_3(double id0[]);
  public void PlaceWidget(double id0[])
    { PlaceWidget_3(id0); }

  private native void PlaceWidget_4();
  public void PlaceWidget()
    { PlaceWidget_4(); }

  private native void PlaceWidget_5(double id0,double id1,double id2,double id3,double id4,double id5);
  public void PlaceWidget(double id0,double id1,double id2,double id3,double id4,double id5)
    { PlaceWidget_5(id0,id1,id2,id3,id4,id5); }

  private native void SetInputConnection_6(vtkAlgorithmOutput id0);
  public void SetInputConnection(vtkAlgorithmOutput id0)
    { SetInputConnection_6(id0); }

  private native void SetOrigin_7(double id0,double id1,double id2);
  public void SetOrigin(double id0,double id1,double id2)
    { SetOrigin_7(id0,id1,id2); }

  private native void SetOrigin_8(double id0[]);
  public void SetOrigin(double id0[])
    { SetOrigin_8(id0); }

  private native double[] GetOrigin_9();
  public double[] GetOrigin()
    { return GetOrigin_9(); }

  private native void GetOrigin_10(double id0[]);
  public void GetOrigin(double id0[])
    { GetOrigin_10(id0); }

  private native void SetPoint1_11(double id0,double id1,double id2);
  public void SetPoint1(double id0,double id1,double id2)
    { SetPoint1_11(id0,id1,id2); }

  private native void SetPoint1_12(double id0[]);
  public void SetPoint1(double id0[])
    { SetPoint1_12(id0); }

  private native double[] GetPoint1_13();
  public double[] GetPoint1()
    { return GetPoint1_13(); }

  private native void GetPoint1_14(double id0[]);
  public void GetPoint1(double id0[])
    { GetPoint1_14(id0); }

  private native void SetPoint2_15(double id0,double id1,double id2);
  public void SetPoint2(double id0,double id1,double id2)
    { SetPoint2_15(id0,id1,id2); }

  private native void SetPoint2_16(double id0[]);
  public void SetPoint2(double id0[])
    { SetPoint2_16(id0); }

  private native double[] GetPoint2_17();
  public double[] GetPoint2()
    { return GetPoint2_17(); }

  private native void GetPoint2_18(double id0[]);
  public void GetPoint2(double id0[])
    { GetPoint2_18(id0); }

  private native double[] GetCenter_19();
  public double[] GetCenter()
    { return GetCenter_19(); }

  private native void GetCenter_20(double id0[]);
  public void GetCenter(double id0[])
    { GetCenter_20(id0); }

  private native double[] GetNormal_21();
  public double[] GetNormal()
    { return GetNormal_21(); }

  private native void GetNormal_22(double id0[]);
  public void GetNormal(double id0[])
    { GetNormal_22(id0); }

  private native void GetVector1_23(double id0[]);
  public void GetVector1(double id0[])
    { GetVector1_23(id0); }

  private native void GetVector2_24(double id0[]);
  public void GetVector2(double id0[])
    { GetVector2_24(id0); }

  private native int GetSliceIndex_25();
  public int GetSliceIndex()
    { return GetSliceIndex_25(); }

  private native void SetSliceIndex_26(int id0);
  public void SetSliceIndex(int id0)
    { SetSliceIndex_26(id0); }

  private native double GetSlicePosition_27();
  public double GetSlicePosition()
    { return GetSlicePosition_27(); }

  private native void SetSlicePosition_28(double id0);
  public void SetSlicePosition(double id0)
    { SetSlicePosition_28(id0); }

  private native void SetResliceInterpolate_29(int id0);
  public void SetResliceInterpolate(int id0)
    { SetResliceInterpolate_29(id0); }

  private native int GetResliceInterpolate_30();
  public int GetResliceInterpolate()
    { return GetResliceInterpolate_30(); }

  private native void SetResliceInterpolateToNearestNeighbour_31();
  public void SetResliceInterpolateToNearestNeighbour()
    { SetResliceInterpolateToNearestNeighbour_31(); }

  private native void SetResliceInterpolateToLinear_32();
  public void SetResliceInterpolateToLinear()
    { SetResliceInterpolateToLinear_32(); }

  private native void SetResliceInterpolateToCubic_33();
  public void SetResliceInterpolateToCubic()
    { SetResliceInterpolateToCubic_33(); }

  private native long GetResliceOutput_34();
  public vtkImageData GetResliceOutput() {
    long temp = GetResliceOutput_34();

    if (temp == 0) return null;
    return (vtkImageData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRestrictPlaneToVolume_35(int id0);
  public void SetRestrictPlaneToVolume(int id0)
    { SetRestrictPlaneToVolume_35(id0); }

  private native int GetRestrictPlaneToVolume_36();
  public int GetRestrictPlaneToVolume()
    { return GetRestrictPlaneToVolume_36(); }

  private native void RestrictPlaneToVolumeOn_37();
  public void RestrictPlaneToVolumeOn()
    { RestrictPlaneToVolumeOn_37(); }

  private native void RestrictPlaneToVolumeOff_38();
  public void RestrictPlaneToVolumeOff()
    { RestrictPlaneToVolumeOff_38(); }

  private native void SetUserControlledLookupTable_39(int id0);
  public void SetUserControlledLookupTable(int id0)
    { SetUserControlledLookupTable_39(id0); }

  private native int GetUserControlledLookupTable_40();
  public int GetUserControlledLookupTable()
    { return GetUserControlledLookupTable_40(); }

  private native void UserControlledLookupTableOn_41();
  public void UserControlledLookupTableOn()
    { UserControlledLookupTableOn_41(); }

  private native void UserControlledLookupTableOff_42();
  public void UserControlledLookupTableOff()
    { UserControlledLookupTableOff_42(); }

  private native void SetTextureInterpolate_43(int id0);
  public void SetTextureInterpolate(int id0)
    { SetTextureInterpolate_43(id0); }

  private native int GetTextureInterpolate_44();
  public int GetTextureInterpolate()
    { return GetTextureInterpolate_44(); }

  private native void TextureInterpolateOn_45();
  public void TextureInterpolateOn()
    { TextureInterpolateOn_45(); }

  private native void TextureInterpolateOff_46();
  public void TextureInterpolateOff()
    { TextureInterpolateOff_46(); }

  private native void SetTextureVisibility_47(int id0);
  public void SetTextureVisibility(int id0)
    { SetTextureVisibility_47(id0); }

  private native int GetTextureVisibility_48();
  public int GetTextureVisibility()
    { return GetTextureVisibility_48(); }

  private native void TextureVisibilityOn_49();
  public void TextureVisibilityOn()
    { TextureVisibilityOn_49(); }

  private native void TextureVisibilityOff_50();
  public void TextureVisibilityOff()
    { TextureVisibilityOff_50(); }

  private native void GetPolyData_51(vtkPolyData id0);
  public void GetPolyData(vtkPolyData id0)
    { GetPolyData_51(id0); }

  private native long GetPolyDataAlgorithm_52();
  public vtkPolyDataAlgorithm GetPolyDataAlgorithm() {
    long temp = GetPolyDataAlgorithm_52();

    if (temp == 0) return null;
    return (vtkPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void UpdatePlacement_53();
  public void UpdatePlacement()
    { UpdatePlacement_53(); }

  private native long GetTexture_54();
  public vtkTexture GetTexture() {
    long temp = GetTexture_54();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetColorMap_55();
  public vtkImageMapToColors GetColorMap() {
    long temp = GetColorMap_55();

    if (temp == 0) return null;
    return (vtkImageMapToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetColorMap_56(vtkImageMapToColors id0);
  public void SetColorMap(vtkImageMapToColors id0)
    { SetColorMap_56(id0); }

  private native void SetPlaneProperty_57(vtkProperty id0);
  public void SetPlaneProperty(vtkProperty id0)
    { SetPlaneProperty_57(id0); }

  private native long GetPlaneProperty_58();
  public vtkProperty GetPlaneProperty() {
    long temp = GetPlaneProperty_58();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectedPlaneProperty_59(vtkProperty id0);
  public void SetSelectedPlaneProperty(vtkProperty id0)
    { SetSelectedPlaneProperty_59(id0); }

  private native long GetSelectedPlaneProperty_60();
  public vtkProperty GetSelectedPlaneProperty() {
    long temp = GetSelectedPlaneProperty_60();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPlaneOrientation_61(int id0);
  public void SetPlaneOrientation(int id0)
    { SetPlaneOrientation_61(id0); }

  private native int GetPlaneOrientation_62();
  public int GetPlaneOrientation()
    { return GetPlaneOrientation_62(); }

  private native void SetPlaneOrientationToXAxes_63();
  public void SetPlaneOrientationToXAxes()
    { SetPlaneOrientationToXAxes_63(); }

  private native void SetPlaneOrientationToYAxes_64();
  public void SetPlaneOrientationToYAxes()
    { SetPlaneOrientationToYAxes_64(); }

  private native void SetPlaneOrientationToZAxes_65();
  public void SetPlaneOrientationToZAxes()
    { SetPlaneOrientationToZAxes_65(); }

  private native void SetPicker_66(vtkAbstractPropPicker id0);
  public void SetPicker(vtkAbstractPropPicker id0)
    { SetPicker_66(id0); }

  private native void SetLookupTable_67(vtkLookupTable id0);
  public void SetLookupTable(vtkLookupTable id0)
    { SetLookupTable_67(id0); }

  private native long GetLookupTable_68();
  public vtkLookupTable GetLookupTable() {
    long temp = GetLookupTable_68();

    if (temp == 0) return null;
    return (vtkLookupTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDisplayText_69(int id0);
  public void SetDisplayText(int id0)
    { SetDisplayText_69(id0); }

  private native int GetDisplayText_70();
  public int GetDisplayText()
    { return GetDisplayText_70(); }

  private native void DisplayTextOn_71();
  public void DisplayTextOn()
    { DisplayTextOn_71(); }

  private native void DisplayTextOff_72();
  public void DisplayTextOff()
    { DisplayTextOff_72(); }

  private native void SetCursorProperty_73(vtkProperty id0);
  public void SetCursorProperty(vtkProperty id0)
    { SetCursorProperty_73(id0); }

  private native long GetCursorProperty_74();
  public vtkProperty GetCursorProperty() {
    long temp = GetCursorProperty_74();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMarginProperty_75(vtkProperty id0);
  public void SetMarginProperty(vtkProperty id0)
    { SetMarginProperty_75(id0); }

  private native long GetMarginProperty_76();
  public vtkProperty GetMarginProperty() {
    long temp = GetMarginProperty_76();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMarginSizeX_77(double id0);
  public void SetMarginSizeX(double id0)
    { SetMarginSizeX_77(id0); }

  private native double GetMarginSizeXMinValue_78();
  public double GetMarginSizeXMinValue()
    { return GetMarginSizeXMinValue_78(); }

  private native double GetMarginSizeXMaxValue_79();
  public double GetMarginSizeXMaxValue()
    { return GetMarginSizeXMaxValue_79(); }

  private native double GetMarginSizeX_80();
  public double GetMarginSizeX()
    { return GetMarginSizeX_80(); }

  private native void SetMarginSizeY_81(double id0);
  public void SetMarginSizeY(double id0)
    { SetMarginSizeY_81(id0); }

  private native double GetMarginSizeYMinValue_82();
  public double GetMarginSizeYMinValue()
    { return GetMarginSizeYMinValue_82(); }

  private native double GetMarginSizeYMaxValue_83();
  public double GetMarginSizeYMaxValue()
    { return GetMarginSizeYMaxValue_83(); }

  private native double GetMarginSizeY_84();
  public double GetMarginSizeY()
    { return GetMarginSizeY_84(); }

  private native void SetTextProperty_85(vtkTextProperty id0);
  public void SetTextProperty(vtkTextProperty id0)
    { SetTextProperty_85(id0); }

  private native long GetTextProperty_86();
  public vtkTextProperty GetTextProperty() {
    long temp = GetTextProperty_86();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTexturePlaneProperty_87(vtkProperty id0);
  public void SetTexturePlaneProperty(vtkProperty id0)
    { SetTexturePlaneProperty_87(id0); }

  private native long GetTexturePlaneProperty_88();
  public vtkProperty GetTexturePlaneProperty() {
    long temp = GetTexturePlaneProperty_88();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetWindowLevel_89(double id0,double id1,int id2);
  public void SetWindowLevel(double id0,double id1,int id2)
    { SetWindowLevel_89(id0,id1,id2); }

  private native void GetWindowLevel_90(double id0[]);
  public void GetWindowLevel(double id0[])
    { GetWindowLevel_90(id0); }

  private native double GetWindow_91();
  public double GetWindow()
    { return GetWindow_91(); }

  private native double GetLevel_92();
  public double GetLevel()
    { return GetLevel_92(); }

  private native int GetCursorData_93(double id0[]);
  public int GetCursorData(double id0[])
    { return GetCursorData_93(id0); }

  private native int GetCursorDataStatus_94();
  public int GetCursorDataStatus()
    { return GetCursorDataStatus_94(); }

  private native double[] GetCurrentCursorPosition_95();
  public double[] GetCurrentCursorPosition()
    { return GetCurrentCursorPosition_95(); }

  private native double GetCurrentImageValue_96();
  public double GetCurrentImageValue()
    { return GetCurrentImageValue_96(); }

  private native long GetResliceAxes_97();
  public vtkMatrix4x4 GetResliceAxes() {
    long temp = GetResliceAxes_97();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetReslice_98();
  public vtkImageReslice GetReslice() {
    long temp = GetReslice_98();

    if (temp == 0) return null;
    return (vtkImageReslice)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUseContinuousCursor_99(int id0);
  public void SetUseContinuousCursor(int id0)
    { SetUseContinuousCursor_99(id0); }

  private native int GetUseContinuousCursor_100();
  public int GetUseContinuousCursor()
    { return GetUseContinuousCursor_100(); }

  private native void UseContinuousCursorOn_101();
  public void UseContinuousCursorOn()
    { UseContinuousCursorOn_101(); }

  private native void UseContinuousCursorOff_102();
  public void UseContinuousCursorOff()
    { UseContinuousCursorOff_102(); }

  private native void SetInteraction_103(int id0);
  public void SetInteraction(int id0)
    { SetInteraction_103(id0); }

  private native int GetInteraction_104();
  public int GetInteraction()
    { return GetInteraction_104(); }

  private native void InteractionOn_105();
  public void InteractionOn()
    { InteractionOn_105(); }

  private native void InteractionOff_106();
  public void InteractionOff()
    { InteractionOff_106(); }

  private native void SetLeftButtonAction_107(int id0);
  public void SetLeftButtonAction(int id0)
    { SetLeftButtonAction_107(id0); }

  private native int GetLeftButtonActionMinValue_108();
  public int GetLeftButtonActionMinValue()
    { return GetLeftButtonActionMinValue_108(); }

  private native int GetLeftButtonActionMaxValue_109();
  public int GetLeftButtonActionMaxValue()
    { return GetLeftButtonActionMaxValue_109(); }

  private native int GetLeftButtonAction_110();
  public int GetLeftButtonAction()
    { return GetLeftButtonAction_110(); }

  private native void SetMiddleButtonAction_111(int id0);
  public void SetMiddleButtonAction(int id0)
    { SetMiddleButtonAction_111(id0); }

  private native int GetMiddleButtonActionMinValue_112();
  public int GetMiddleButtonActionMinValue()
    { return GetMiddleButtonActionMinValue_112(); }

  private native int GetMiddleButtonActionMaxValue_113();
  public int GetMiddleButtonActionMaxValue()
    { return GetMiddleButtonActionMaxValue_113(); }

  private native int GetMiddleButtonAction_114();
  public int GetMiddleButtonAction()
    { return GetMiddleButtonAction_114(); }

  private native void SetRightButtonAction_115(int id0);
  public void SetRightButtonAction(int id0)
    { SetRightButtonAction_115(id0); }

  private native int GetRightButtonActionMinValue_116();
  public int GetRightButtonActionMinValue()
    { return GetRightButtonActionMinValue_116(); }

  private native int GetRightButtonActionMaxValue_117();
  public int GetRightButtonActionMaxValue()
    { return GetRightButtonActionMaxValue_117(); }

  private native int GetRightButtonAction_118();
  public int GetRightButtonAction()
    { return GetRightButtonAction_118(); }

  private native void SetLeftButtonAutoModifier_119(int id0);
  public void SetLeftButtonAutoModifier(int id0)
    { SetLeftButtonAutoModifier_119(id0); }

  private native int GetLeftButtonAutoModifierMinValue_120();
  public int GetLeftButtonAutoModifierMinValue()
    { return GetLeftButtonAutoModifierMinValue_120(); }

  private native int GetLeftButtonAutoModifierMaxValue_121();
  public int GetLeftButtonAutoModifierMaxValue()
    { return GetLeftButtonAutoModifierMaxValue_121(); }

  private native int GetLeftButtonAutoModifier_122();
  public int GetLeftButtonAutoModifier()
    { return GetLeftButtonAutoModifier_122(); }

  private native void SetMiddleButtonAutoModifier_123(int id0);
  public void SetMiddleButtonAutoModifier(int id0)
    { SetMiddleButtonAutoModifier_123(id0); }

  private native int GetMiddleButtonAutoModifierMinValue_124();
  public int GetMiddleButtonAutoModifierMinValue()
    { return GetMiddleButtonAutoModifierMinValue_124(); }

  private native int GetMiddleButtonAutoModifierMaxValue_125();
  public int GetMiddleButtonAutoModifierMaxValue()
    { return GetMiddleButtonAutoModifierMaxValue_125(); }

  private native int GetMiddleButtonAutoModifier_126();
  public int GetMiddleButtonAutoModifier()
    { return GetMiddleButtonAutoModifier_126(); }

  private native void SetRightButtonAutoModifier_127(int id0);
  public void SetRightButtonAutoModifier(int id0)
    { SetRightButtonAutoModifier_127(id0); }

  private native int GetRightButtonAutoModifierMinValue_128();
  public int GetRightButtonAutoModifierMinValue()
    { return GetRightButtonAutoModifierMinValue_128(); }

  private native int GetRightButtonAutoModifierMaxValue_129();
  public int GetRightButtonAutoModifierMaxValue()
    { return GetRightButtonAutoModifierMaxValue_129(); }

  private native int GetRightButtonAutoModifier_130();
  public int GetRightButtonAutoModifier()
    { return GetRightButtonAutoModifier_130(); }

  public vtkImagePlaneWidget() { super(); }

  public vtkImagePlaneWidget(long id) { super(id); }
  public native long   VTKInit();

}
